<?php
/**
 * Royal Jewellery functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Royal Jewellery
 */

include get_theme_file_path( 'vendor/wptrt/autoload/src/Royal_Jewellery_Loader.php' );

$Royal_Jewellery_Loader = new \WPTRT\Autoload\Royal_Jewellery_Loader();

$Royal_Jewellery_Loader->royal_jewellery_add( 'WPTRT\\Customize\\Section', get_theme_file_path( 'vendor/wptrt/customize-section-button/src' ) );

$Royal_Jewellery_Loader->royal_jewellery_register();

if ( ! function_exists( 'royal_jewellery_setup' ) ) :

	function royal_jewellery_setup() {

		/*
		 * Enable support for Post Formats.
		 *
		 * See: https://codex.wordpress.org/Post_Formats
		*/
		add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

		load_theme_textdomain( 'royal-jewellery', get_template_directory() . '/languages' );
		add_theme_support( 'woocommerce' );
		add_theme_support( "responsive-embeds" );
		add_theme_support( "align-wide" );
		add_theme_support( "wp-block-styles" );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
        add_image_size('royal-jewellery-featured-header-image', 2000, 660, true);

        register_nav_menus( array(
            'primary' => esc_html__( 'Primary','royal-jewellery' ),
	        'footer'=> esc_html__( 'Footer Menu','royal-jewellery' ),
        ) );

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_theme_support( 'custom-background', apply_filters( 'royal_jewellery_custom_background_args', array(
			'default-color' => 'f7ebe5',
			'default-image' => '',
		) ) );

		add_theme_support( 'customize-selective-refresh-widgets' );

		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 50,
			'flex-width'  => true,
		) );

		add_editor_style( array( '/editor-style.css' ) );
		add_action('wp_ajax_royal_jewellery_dismissable_notice', 'royal_jewellery_dismissable_notice');
	}
endif;
add_action( 'after_setup_theme', 'royal_jewellery_setup' );


function royal_jewellery_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'royal_jewellery_content_width', 1170 );
}
add_action( 'after_setup_theme', 'royal_jewellery_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function royal_jewellery_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'royal-jewellery' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'royal-jewellery' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 1', 'royal-jewellery' ),
		'id'            => 'royal-jewellery-footer1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 2', 'royal-jewellery' ),
		'id'            => 'royal-jewellery-footer2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 3', 'royal-jewellery' ),
		'id'            => 'royal-jewellery-footer3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'royal_jewellery_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function royal_jewellery_scripts() {

	require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );

	wp_enqueue_style(
		'nunito',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Nunito+Sans:ital,opsz,wght@0,6..12,200;0,6..12,300;0,6..12,400;0,6..12,500;0,6..12,600;0,6..12,700;0,6..12,800;0,6..12,900;0,6..12,1000;1,6..12,200;1,6..12,300;1,6..12,400;1,6..12,500;1,6..12,600;1,6..12,700;1,6..12,800;1,6..12,900;1,6..12,1000&display=swap' ),
		array(),
		'1.0'
	);

	wp_enqueue_style(
		'cormorant',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Cormorant+Garamond:ital,wght@0,300;0,400;0,500;0,600;0,700;1,300;1,400;1,500;1,600;1,700&display=swap' ),
		array(),
		'1.0'
	);

	wp_enqueue_style( 'royal-jewellery-block-editor-style', get_theme_file_uri('/assets/css/block-editor-style.css') );

	// load bootstrap css
    wp_enqueue_style( 'bootstrap-css', get_template_directory_uri() . '/assets/css/bootstrap.css');

    wp_enqueue_style( 'owl.carousel-css', get_template_directory_uri() . '/assets/css/owl.carousel.css');

	wp_enqueue_style( 'royal-jewellery-style', get_stylesheet_uri() );
	require get_parent_theme_file_path( '/custom-option.php' );
	wp_add_inline_style( 'royal-jewellery-style',$royal_jewellery_theme_css );

	wp_style_add_data('royal-jewellery-basic-style', 'rtl', 'replace');

	// fontawesome
	wp_enqueue_style( 'fontawesome-style', get_template_directory_uri() .'/assets/css/fontawesome/css/all.css' );

    wp_enqueue_script('royal-jewellery-theme-js', get_template_directory_uri() . '/assets/js/theme-script.js', array('jquery'), '', true );

    wp_enqueue_script('owl.carousel-js', get_template_directory_uri() . '/assets/js/owl.carousel.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'royal_jewellery_scripts' );

/**
 * Enqueue Preloader.
 */
function royal_jewellery_preloader() {

  $royal_jewellery_theme_color_css = '';
  $royal_jewellery_preloader_bg_color = get_theme_mod('royal_jewellery_preloader_bg_color');
  $royal_jewellery_preloader_dot_1_color = get_theme_mod('royal_jewellery_preloader_dot_1_color');
  $royal_jewellery_preloader_dot_2_color = get_theme_mod('royal_jewellery_preloader_dot_2_color');
  $royal_jewellery_logo_max_height = get_theme_mod('royal_jewellery_logo_max_height');

  	if(get_theme_mod('royal_jewellery_logo_max_height') == '') {
		$royal_jewellery_logo_max_height = '24';
	}

	if(get_theme_mod('royal_jewellery_preloader_bg_color') == '') {
		$royal_jewellery_preloader_bg_color = '#CA841A';
	}
	if(get_theme_mod('royal_jewellery_preloader_dot_1_color') == '') {
		$royal_jewellery_preloader_dot_1_color = '#ffffff';
	}
	if(get_theme_mod('royal_jewellery_preloader_dot_2_color') == '') {
		$royal_jewellery_preloader_dot_2_color = '#111111';
	}
	$royal_jewellery_theme_color_css = '
		.custom-logo-link img{
			max-height: '.esc_attr($royal_jewellery_logo_max_height).'px;
	 	}
		.loading{
			background-color: '.esc_attr($royal_jewellery_preloader_bg_color).';
		 }
		 @keyframes loading {
		  0%,
		  100% {
		  	transform: translatey(-2.5rem);
		    background-color: '.esc_attr($royal_jewellery_preloader_dot_1_color).';
		  }
		  50% {
		  	transform: translatey(2.5rem);
		    background-color: '.esc_attr($royal_jewellery_preloader_dot_2_color).';
		  }
		}
	';
    wp_add_inline_style( 'royal-jewellery-style',$royal_jewellery_theme_color_css );

}
add_action( 'wp_enqueue_scripts', 'royal_jewellery_preloader' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/* TGM. */
require get_parent_theme_file_path( '/inc/tgm.php' );

function royal_jewellery_sanitize_select( $input, $setting ){
    $input = sanitize_key($input);
    $choices = $setting->manager->get_control( $setting->id )->choices;
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

function royal_jewellery_sanitize_checkbox( $input ) {
  // Boolean check
  return ( ( isset( $input ) && true == $input ) ? true : false );
}

/*radio button sanitization*/
function royal_jewellery_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function royal_jewellery_sanitize_number_absint( $number, $setting ) {
	// Ensure $number is an absolute integer (whole number, zero or greater).
	$number = absint( $number );

	// If the input is an absolute integer, return it; otherwise, return the default
	return ( $number ? $number : $setting->default );
}

function royal_jewellery_sanitize_number_range( $number, $setting ) {
	
	// Ensure input is an absolute integer.
	$number = absint( $number );
	
	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;
	
	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
	
	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
	
	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
	
	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}

/*dropdown page sanitization*/
function royal_jewellery_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'royal_jewellery_loop_columns');
if (!function_exists('royal_jewellery_loop_columns')) {
	function royal_jewellery_loop_columns() {
		$columns = get_theme_mod( 'royal_jewellery_products_per_row', 3 );
		return $columns; // 3 products per row
	}
}

//Change number of products that are displayed per page (shop page)
add_filter( 'loop_shop_per_page', 'royal_jewellery_shop_per_page', 9 );
function royal_jewellery_shop_per_page( $cols ) {
  	$cols = get_theme_mod( 'royal_jewellery_product_per_page', 9 );
	return $cols;
}

/**
 * Get CSS
 */

function royal_jewellery_getpage_css($hook) {
	wp_register_script( 'admin-notice-script', get_template_directory_uri() . '/inc/admin/js/admin-notice-script.js', array( 'jquery' ) );
    wp_localize_script('admin-notice-script','royal_jewellery',
		array('admin_ajax'	=>	admin_url('admin-ajax.php'),'wpnonce'  =>	wp_create_nonce('royal_jewellery_dismissed_notice_nonce')
		)
	);
	wp_enqueue_script('admin-notice-script');

    wp_localize_script( 'admin-notice-script', 'royal_jewellery_ajax_object',
        array( 'ajax_url' => admin_url( 'admin-ajax.php' ) )
    );
	if ( 'appearance_page_royal-jewellery-info' != $hook ) {
		return;
	}
	wp_enqueue_style( 'royal-jewellery-demo-style', get_template_directory_uri() . '/assets/css/demo.css' );
}
add_action( 'admin_enqueue_scripts', 'royal_jewellery_getpage_css' );

if ( ! defined( 'ROYAL_JEWELLERY_CONTACT_SUPPORT' ) ) {
define('ROYAL_JEWELLERY_CONTACT_SUPPORT',__('https://wordpress.org/support/theme/royal-jewellery/','royal-jewellery'));
}
if ( ! defined( 'ROYAL_JEWELLERY_REVIEW' ) ) {
define('ROYAL_JEWELLERY_REVIEW',__('https://wordpress.org/support/theme/royal-jewellery/reviews/','royal-jewellery'));
}
if ( ! defined( 'ROYAL_JEWELLERY_LIVE_DEMO' ) ) {
define('ROYAL_JEWELLERY_LIVE_DEMO',__('https://demo.themagnifico.net/royal-jewellery/','royal-jewellery'));
}
if ( ! defined( 'ROYAL_JEWELLERY_GET_PREMIUM_PRO' ) ) {
define('ROYAL_JEWELLERY_GET_PREMIUM_PRO',__('https://www.themagnifico.net/products/jewellery-store-wordpress-theme','royal-jewellery'));
}
if ( ! defined( 'ROYAL_JEWELLERY_PRO_DOC' ) ) {
define('ROYAL_JEWELLERY_PRO_DOC',__('https://demo.themagnifico.net/eard/wathiqa/royal-jewellery-pro-doc/','royal-jewellery'));
}
if ( ! defined( 'ROYAL_JEWELLERY_FREE_DOC' ) ) {
define('ROYAL_JEWELLERY_FREE_DOC',__('https://demo.themagnifico.net/eard/wathiqa/royal-jewellery-free-doc/','royal-jewellery'));
}

add_action('admin_menu', 'royal_jewellery_themepage');
function royal_jewellery_themepage(){

	$royal_jewellery_theme_test = wp_get_theme();

	$royal_jewellery_theme_info = add_theme_page( __('Theme Options','royal-jewellery'), __(' Theme Options','royal-jewellery'), 'manage_options', 'royal-jewellery-info.php', 'royal_jewellery_info_page' );
}

function royal_jewellery_info_page() {
	$royal_jewellery_theme_user = wp_get_current_user();
	$royal_jewellery_theme = wp_get_theme();
	?>
	<div class="wrap about-wrap royal-jewellery-add-css">
		<div>
			<h1>
				<?php esc_html_e('Welcome To ','royal-jewellery'); ?><?php echo esc_html( $royal_jewellery_theme ); ?>
			</h1>
			<div class="feature-section three-col">
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Contact Support", "royal-jewellery"); ?></h3>
						<p><?php esc_html_e("Thank you for trying Royal Jewellery , feel free to contact us for any support regarding our theme.", "royal-jewellery"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( ROYAL_JEWELLERY_CONTACT_SUPPORT ); ?>" class="button button-primary get">
							<?php esc_html_e("Contact Support", "royal-jewellery"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Checkout Premium", "royal-jewellery"); ?></h3>
						<p><?php esc_html_e("Our premium theme comes with extended features like demo content import , responsive layouts etc.", "royal-jewellery"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( ROYAL_JEWELLERY_GET_PREMIUM_PRO ); ?>" class="button button-primary get prem">
							<?php esc_html_e("Get Premium", "royal-jewellery"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Review", "royal-jewellery"); ?></h3>
						<p><?php esc_html_e("If You love Royal Jewellery theme then we would appreciate your review about our theme.", "royal-jewellery"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( ROYAL_JEWELLERY_REVIEW ); ?>" class="button button-primary get">
							<?php esc_html_e("Review", "royal-jewellery"); ?>
						</a></p>
					</div>
				</div>

				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Free Documentation", "royal-jewellery"); ?></h3>
						<p><?php esc_html_e("Our guide is available if you require any help configuring and setting up the theme. Easy and quick way to setup the theme.", "royal-jewellery"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( ROYAL_JEWELLERY_FREE_DOC ); ?>" class="button button-primary get">
							<?php esc_html_e("Free Documentation", "royal-jewellery"); ?>
						</a></p>
					</div>
				</div>
			</div>
		</div>
		<hr>

		<h2><?php esc_html_e("Free Vs Premium","royal-jewellery"); ?></h2>
		<div class="royal-jewellery-button-container">
			<a target="_blank" href="<?php echo esc_url( ROYAL_JEWELLERY_PRO_DOC ); ?>" class="button button-primary get">
				<?php esc_html_e("Checkout Documentation", "royal-jewellery"); ?>
			</a>
			<a target="_blank" href="<?php echo esc_url( ROYAL_JEWELLERY_LIVE_DEMO ); ?>" class="button button-primary get">
				<?php esc_html_e("View Theme Demo", "royal-jewellery"); ?>
			</a>
		</div>


		<table class="wp-list-table widefat">
			<thead class="table-book">
				<tr>
					<th><strong><?php esc_html_e("Theme Feature", "royal-jewellery"); ?></strong></th>
					<th><strong><?php esc_html_e("Basic Version", "royal-jewellery"); ?></strong></th>
					<th><strong><?php esc_html_e("Premium Version", "royal-jewellery"); ?></strong></th>
				</tr>
			</thead>

			<tbody>
				<tr>
					<td><?php esc_html_e("Header Background Color", "royal-jewellery"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Navigation Logo Or Text", "royal-jewellery"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Hide Logo Text", "royal-jewellery"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Premium Support", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Fully SEO Optimized", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Recent Posts Widget", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Easy Google Fonts", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Pagespeed Plugin", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Header Image On Front Page", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Show Header Everywhere", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Text On Header Image", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Full Width (Hide Sidebar)", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Upper Widgets On Front Page", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Replace Copyright Text", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Upper Widgets Colors", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Navigation Color", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Post/Page Color", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Blog Feed Color", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Footer Color", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Sidebar Color", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Background Color", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Importable Demo Content	", "royal-jewellery"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
			</tbody>
		</table>
		<div class="royal-jewellery-button-container">
			<a target="_blank" href="<?php echo esc_url( ROYAL_JEWELLERY_GET_PREMIUM_PRO ); ?>" class="button button-primary get prem">
				<?php esc_html_e("Go Premium", "royal-jewellery"); ?>
			</a>
		</div>
	</div>
	<?php
}

//Admin Notice For Getstart
function royal_jewellery_ajax_notice_handler() {
    if ( isset( $_POST['type'] ) ) {
        $type = sanitize_text_field( wp_unslash( $_POST['type'] ) );
        update_option( 'dismissed-' . $type, TRUE );
    }
}

function royal_jewellery_deprecated_hook_admin_notice() {

    $dismissed = get_user_meta(get_current_user_id(), 'royal_jewellery_dismissable_notice', true);
    if ( !$dismissed) { ?>
        <div class="updated notice notice-success is-dismissible notice-get-started-class" data-notice="get_started" style="background: #f7f9f9; padding: 20px 10px; display: flex;">
	    	<div class="tm-admin-image">
	    		<img style="width: 100%;max-width: 320px;line-height: 40px;display: inline-block;vertical-align: top;border: 2px solid #ddd;border-radius: 4px;" src="<?php echo esc_url(get_stylesheet_directory_uri()) .'/screenshot.png'; ?>" />
	    	</div>
	    	<div class="tm-admin-content" style="padding-left: 30px; align-self: center">
	    		<h2 style="font-weight: 600;line-height: 1.3; margin: 0px;"><?php esc_html_e('Thank You For Choosing ', 'royal-jewellery'); ?><?php echo wp_get_theme(); ?><h2>
	    		<p style="color: #3c434a; font-weight: 400; margin-bottom: 30px;"><?php _e('Get Started With Theme By Clicking On Getting Started.', 'royal-jewellery'); ?><p>
	        	<a class="admin-notice-btn button button-primary button-hero" href="<?php echo esc_url( admin_url( 'themes.php?page=royal-jewellery-info.php' )); ?>"><?php esc_html_e( 'Get started', 'royal-jewellery' ) ?></a>
	        	<a class="admin-notice-btn button button-primary button-hero" target="_blank" href="<?php echo esc_url( ROYAL_JEWELLERY_FREE_DOC ); ?>"><?php esc_html_e( 'Documentation', 'royal-jewellery' ) ?></a>
	        	<span style="padding-top: 15px; display: inline-block; padding-left: 8px;">
	        	<span class="dashicons dashicons-admin-links"></span>
	        	<a class="admin-notice-btn"	 target="_blank" href="<?php echo esc_url( ROYAL_JEWELLERY_LIVE_DEMO ); ?>"><?php esc_html_e( 'View Demo', 'royal-jewellery' ) ?></a>
	        	</span>
	    	</div>
        </div>
    <?php }
}

add_action( 'admin_notices', 'royal_jewellery_deprecated_hook_admin_notice' );

function royal_jewellery_switch_theme() {
    delete_user_meta(get_current_user_id(), 'royal_jewellery_dismissable_notice');
}
add_action('after_switch_theme', 'royal_jewellery_switch_theme');
function royal_jewellery_dismissable_notice() {
    update_user_meta(get_current_user_id(), 'royal_jewellery_dismissable_notice', true);
    die();
}