<?php
/**
 * Royal Jewellery Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Royal Jewellery
 */

if ( ! defined( 'ROYAL_JEWELLERY_URL' ) ) {
    define( 'ROYAL_JEWELLERY_URL', esc_url( 'https://www.themagnifico.net/products/jewellery-store-wordpress-theme', 'royal-jewellery') );
}
if ( ! defined( 'ROYAL_JEWELLERY_TEXT' ) ) {
    define( 'ROYAL_JEWELLERY_TEXT', __( 'Royal Jewellery Pro','royal-jewellery' ));
}
if ( ! defined( 'ROYAL_JEWELLERY_BUY_TEXT' ) ) {
    define( 'ROYAL_JEWELLERY_BUY_TEXT', __( 'Buy Royal Jewellery Pro','royal-jewellery' ));
}

use WPTRT\Customize\Section\Royal_Jewellery_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Royal_Jewellery_Button::class );

    $manager->add_section(
        new Royal_Jewellery_Button( $manager, 'royal_jewellery_pro', [
            'title'       => esc_html( ROYAL_JEWELLERY_TEXT,'royal-jewellery' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'royal-jewellery' ),
            'button_url'  => esc_url( ROYAL_JEWELLERY_URL )
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'royal-jewellery-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'royal-jewellery-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function royal_jewellery_customize_register($wp_customize){

    // Pro Version
    class Royal_Jewellery_Customize_Pro_Version extends WP_Customize_Control {
        public $type = 'pro_options';

        public function render_content() {
            echo '<span>For More <strong>'. esc_html( $this->label ) .'</strong>?</span>';
            echo '<a href="'. esc_url($this->description) .'" target="_blank">';
                echo '<span class="dashicons dashicons-info"></span>';
                echo '<strong> '. esc_html( ROYAL_JEWELLERY_BUY_TEXT,'royal-jewellery' ) .'<strong></a>';
            echo '</a>';
        }
    }

    // Custom Controls
    function Royal_Jewellery_sanitize_custom_control( $input ) {
        return $input;
    }

    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    //Logo
    $wp_customize->add_setting('royal_jewellery_logo_max_height',array(
        'default'   => '24',
        'sanitize_callback' => 'royal_jewellery_sanitize_number_absint'
    ));
    $wp_customize->add_control('royal_jewellery_logo_max_height',array(
        'label' => esc_html__('Logo Width','royal-jewellery'),
        'section'   => 'title_tagline',
        'type'      => 'number'
    ));

    $wp_customize->add_setting('royal_jewellery_logo_title_text', array(
        'default' => true,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'royal_jewellery_logo_title_text',array(
        'label'          => __( 'Enable Disable Title', 'royal-jewellery' ),
        'section'        => 'title_tagline',
        'settings'       => 'royal_jewellery_logo_title_text',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('royal_jewellery_theme_description', array(
        'default' => false,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'royal_jewellery_theme_description',array(
        'label'          => __( 'Enable Disable Tagline', 'royal-jewellery' ),
        'section'        => 'title_tagline',
        'settings'       => 'royal_jewellery_theme_description',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('royal_jewellery_logo_title_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'royal_jewellery_logo_title_color', array(
        'label'    => __('Site Title Color', 'royal-jewellery'),
        'section'  => 'title_tagline'
    )));

    $wp_customize->add_setting('royal_jewellery_logo_tagline_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'royal_jewellery_logo_tagline_color', array(
        'label'    => __('Site Tagline Color', 'royal-jewellery'),
        'section'  => 'title_tagline'
    )));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_logo', array(
        'sanitize_callback' => 'Royal_Jewellery_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Royal_Jewellery_Customize_Pro_Version ( $wp_customize,'pro_version_logo', array(
        'section'     => 'title_tagline',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'royal-jewellery' ),
        'description' => esc_url( ROYAL_JEWELLERY_URL ),
        'priority'    => 100
    )));

    // General Settings
     $wp_customize->add_section('royal_jewellery_general_settings',array(
        'title' => esc_html__('General Settings','royal-jewellery'),
        'priority'   => 30,
    ));

    $wp_customize->add_setting('royal_jewellery_preloader_hide', array(
        'default' => 0,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'royal_jewellery_preloader_hide',array(
        'label'          => __( 'Show Theme Preloader', 'royal-jewellery' ),
        'section'        => 'royal_jewellery_general_settings',
        'settings'       => 'royal_jewellery_preloader_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting( 'royal_jewellery_preloader_bg_color', array(
        'default' => '#CA841A',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'royal_jewellery_preloader_bg_color', array(
        'label' => esc_html__('Preloader Background Color','royal-jewellery'),
        'section' => 'royal_jewellery_general_settings',
        'settings' => 'royal_jewellery_preloader_bg_color'
    )));

    $wp_customize->add_setting( 'royal_jewellery_preloader_dot_1_color', array(
        'default' => '#ffffff',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'royal_jewellery_preloader_dot_1_color', array(
        'label' => esc_html__('Preloader First Dot Color','royal-jewellery'),
        'section' => 'royal_jewellery_general_settings',
        'settings' => 'royal_jewellery_preloader_dot_1_color'
    )));

    $wp_customize->add_setting( 'royal_jewellery_preloader_dot_2_color', array(
        'default' => '#111111',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'royal_jewellery_preloader_dot_2_color', array(
        'label' => esc_html__('Preloader Second Dot Color','royal-jewellery'),
        'section' => 'royal_jewellery_general_settings',
        'settings' => 'royal_jewellery_preloader_dot_2_color'
    )));

    $wp_customize->add_setting('royal_jewellery_scroll_hide', array(
        'default' => false,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'royal_jewellery_scroll_hide',array(
        'label'          => __( 'Show Theme Scroll To Top', 'royal-jewellery' ),
        'section'        => 'royal_jewellery_general_settings',
        'settings'       => 'royal_jewellery_scroll_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('royal_jewellery_scroll_top_position',array(
        'default' => 'Right',
        'sanitize_callback' => 'royal_jewellery_sanitize_choices'
    ));
    $wp_customize->add_control('royal_jewellery_scroll_top_position',array(
        'label'       => esc_html__( 'Scroll To Top Positions','royal-jewellery' ),
        'type' => 'radio',
        'section' => 'royal_jewellery_general_settings',
        'choices' => array(
            'Right' => __('Right','royal-jewellery'),
            'Left' => __('Left','royal-jewellery'),
            'Center' => __('Center','royal-jewellery')
        ),
    ) );

    $wp_customize->add_setting( 'royal_jewellery_scroll_to_top_border_radius', array(
        'default'              => '',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'royal_jewellery_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'royal_jewellery_scroll_to_top_border_radius', array(
        'label'       => esc_html__( 'Scroll To Top Border Radius','royal-jewellery' ),
        'section'     => 'royal_jewellery_general_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    // Product Columns
    $wp_customize->add_setting( 'royal_jewellery_products_per_row' , array(
       'default'           => '3',
       'transport'         => 'refresh',
       'sanitize_callback' => 'royal_jewellery_sanitize_select',
    ) );

   $wp_customize->add_control('royal_jewellery_products_per_row', array(
       'label' => __( 'Product per row', 'royal-jewellery' ),
       'section'  => 'royal_jewellery_general_settings',
       'type'     => 'select',
       'choices'  => array(
           '2' => '2',
           '3' => '3',
           '4' => '4',
       ),
   ) );

   $wp_customize->add_setting('royal_jewellery_product_per_page',array(
        'default'   => '9',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('royal_jewellery_product_per_page',array(
        'label' => __('Product per page','royal-jewellery'),
        'section'   => 'royal_jewellery_general_settings',
        'type'      => 'number'
    ));

    //Woocommerce shop page Sidebar
    $wp_customize->add_setting('royal_jewellery_woocommerce_shop_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'royal_jewellery_woocommerce_shop_page_sidebar',array(
        'label'          => __( 'Hide Shop Page Sidebar', 'royal-jewellery' ),
        'section'        => 'royal_jewellery_general_settings',
        'settings'       => 'royal_jewellery_woocommerce_shop_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('royal_jewellery_shop_page_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'royal_jewellery_sanitize_choices'
    ));
    $wp_customize->add_control('royal_jewellery_shop_page_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Shop Page Sidebar','royal-jewellery'),
        'section' => 'royal_jewellery_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','royal-jewellery'),
            'Right Sidebar' => __('Right Sidebar','royal-jewellery'),
        ),
    ) );

    //Woocommerce Single Product page Sidebar
    $wp_customize->add_setting('royal_jewellery_woocommerce_single_product_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'royal_jewellery_woocommerce_single_product_page_sidebar',array(
        'label'          => __( 'Hide Single Product Page Sidebar', 'royal-jewellery' ),
        'section'        => 'royal_jewellery_general_settings',
        'settings'       => 'royal_jewellery_woocommerce_single_product_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('royal_jewellery_single_product_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'royal_jewellery_sanitize_choices'
    ));
    $wp_customize->add_control('royal_jewellery_single_product_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Single Product Page Sidebar','royal-jewellery'),
        'section' => 'royal_jewellery_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','royal-jewellery'),
            'Right Sidebar' => __('Right Sidebar','royal-jewellery'),
        ),
    ) );

   $wp_customize->add_setting('royal_jewellery_woocommerce_product_sale',array(
        'default' => 'Left',
        'sanitize_callback' => 'royal_jewellery_sanitize_choices'
    ));
    $wp_customize->add_control('royal_jewellery_woocommerce_product_sale',array(
        'label'       => esc_html__( 'Woocommerce Product Sale Positions','royal-jewellery' ),
        'type' => 'radio',
        'section' => 'royal_jewellery_general_settings',
        'choices' => array(
            'Right' => __('Right','royal-jewellery'),
            'Left' => __('Left','royal-jewellery'),
            'Center' => __('Center','royal-jewellery')
        ),
    ) );

    $wp_customize->add_setting( 'royal_jewellery_woo_product_sale_border_radius', array(
        'default'              => '',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'royal_jewellery_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'royal_jewellery_woo_product_sale_border_radius', array(
        'label'       => esc_html__( 'Woocommerce Product Sale Border Radius','royal-jewellery' ),
        'section'     => 'royal_jewellery_general_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    //Products border radius
    $wp_customize->add_setting( 'royal_jewellery_woo_product_border_radius', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'royal_jewellery_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'royal_jewellery_woo_product_border_radius', array(
        'label'       => esc_html__( 'Product Border Radius','royal-jewellery' ),
        'section'     => 'royal_jewellery_general_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 150,
        ),
    ) );

    // Pro Version
    $wp_customize->add_setting( 'pro_version_general_setting', array(
        'sanitize_callback' => 'Royal_Jewellery_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Royal_Jewellery_Customize_Pro_Version ( $wp_customize,'pro_version_general_setting', array(
        'section'     => 'royal_jewellery_general_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'royal-jewellery' ),
        'description' => esc_url( ROYAL_JEWELLERY_URL ),
        'priority'    => 100
    )));

    //TopBar
    $wp_customize->add_section('royal_jewellery_topbar',array(
        'title' => esc_html__('Topbar Option','royal-jewellery')
    ));

    $wp_customize->add_setting('royal_jewellery_topbar_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('royal_jewellery_topbar_text',array(
        'label' => esc_html__('Topbar Text','royal-jewellery'),
        'section' => 'royal_jewellery_topbar',
        'setting' => 'royal_jewellery_topbar_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('royal_jewellery_search_setting', array(
        'default' => false,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'royal_jewellery_search_setting',array(
        'label'          => __( 'Enable Header Search', 'royal-jewellery' ),
        'section'        => 'royal_jewellery_topbar',
        'settings'       => 'royal_jewellery_search_setting',
        'type'           => 'checkbox',
    )));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_topbar_sec', array(
        'sanitize_callback' => 'Royal_Jewellery_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Royal_Jewellery_Customize_Pro_Version ( $wp_customize,'pro_version_topbar_sec', array(
        'section'     => 'royal_jewellery_topbar',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'royal-jewellery' ),
        'description' => esc_url( ROYAL_JEWELLERY_URL ),
        'priority'    => 100
    )));

     //Slider
    $wp_customize->add_section('royal_jewellery_top_slider',array(
        'title' => esc_html__('Slider Settings','royal-jewellery'),
        'description' => esc_html__('Here you have to add 3 different pages in below dropdown. Note: Image Dimensions 1400 x 550 px','royal-jewellery')
    ));

    for ( $royal_jewellery_count = 1; $royal_jewellery_count <= 3; $royal_jewellery_count++ ) {

        $wp_customize->add_setting( 'royal_jewellery_top_slider_page' . $royal_jewellery_count, array(
            'default'           => '',
            'sanitize_callback' => 'royal_jewellery_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'royal_jewellery_top_slider_page' . $royal_jewellery_count, array(
            'label'    => __( 'Select Slide Page', 'royal-jewellery' ),
            'section'  => 'royal_jewellery_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    //Slider height
    $wp_customize->add_setting('royal_jewellery_slider_img_height',array(
        'default'=> '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('royal_jewellery_slider_img_height',array(
        'label' => __('Slider Height','royal-jewellery'),
        'description'   => __('Add the slider height in px(eg. 500px).','royal-jewellery'),
        'input_attrs' => array(
            'placeholder' => __( '500px', 'royal-jewellery' ),
        ),
        'section'=> 'royal_jewellery_top_slider',
        'type'=> 'text'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_slider', array(
        'sanitize_callback' => 'Royal_Jewellery_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Royal_Jewellery_Customize_Pro_Version ( $wp_customize,'pro_version_slider', array(
        'section'     => 'royal_jewellery_top_slider',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'royal-jewellery' ),
        'description' => esc_url( ROYAL_JEWELLERY_URL ),
        'priority'    => 100
    )));

    // Trending Product
    $wp_customize->add_section('royal_jewellery_product_section',array(
        'title' => esc_html__('Trending Product Option','royal-jewellery'),
    ));

    $wp_customize->add_setting('royal_jewellery_product_image',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control(
        new WP_Customize_Image_Control( $wp_customize,'royal_jewellery_product_image',array(
            'label' => __('Section Image','royal-jewellery'),
            'section' => 'royal_jewellery_product_section',
            'settings' => 'royal_jewellery_product_image'
    )));

    $wp_customize->add_setting('royal_jewellery_product_main_heading',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('royal_jewellery_product_main_heading',array(
        'label' => esc_html__('Heading','royal-jewellery'),
        'section' => 'royal_jewellery_product_section',
        'setting' => 'royal_jewellery_product_main_heading',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('royal_jewellery_product_main_discription',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('royal_jewellery_product_main_discription',array(
        'label' => esc_html__('Content','royal-jewellery'),
        'section' => 'royal_jewellery_product_section',
        'setting' => 'royal_jewellery_product_main_discription',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('royal_jewellery_product_main_button_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('royal_jewellery_product_main_button_text',array(
        'label' => esc_html__('Button Text','royal-jewellery'),
        'section' => 'royal_jewellery_product_section',
        'setting' => 'royal_jewellery_product_main_button_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('royal_jewellery_product_main_button_url',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('royal_jewellery_product_main_button_url',array(
        'label' => esc_html__('Button Url','royal-jewellery'),
        'section' => 'royal_jewellery_product_section',
        'setting' => 'royal_jewellery_product_main_button_url',
        'type'  => 'text'
    ));

    if(class_exists('woocommerce')){

        $wp_customize->add_setting('royal_jewellery_home_product_per_page',array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control('royal_jewellery_home_product_per_page',array(
            'label' => esc_html__('No Of Products','royal-jewellery'),
            'section' => 'royal_jewellery_product_section',
            'setting' => 'royal_jewellery_home_product_per_page',
            'type'  => 'number'
        ));
        
        $royal_jewellery_args = array(
           'type'                     => 'product',
            'child_of'                 => 0,
            'parent'                   => '',
            'orderby'                  => 'term_group',
            'order'                    => 'ASC',
            'hide_empty'               => false,
            'hierarchical'             => 1,
            'number'                   => '',
            'taxonomy'                 => 'product_cat',
            'pad_counts'               => false
        );
        $categories = get_categories( $royal_jewellery_args );
        $cats = array();
        $i = 0;
        foreach($categories as $category){
            if($i==0){
                $default = $category->slug;
                $i++;
            }
            $cats[$category->slug] = $category->name;
        }
        $wp_customize->add_setting('royal_jewellery_home_product',array(
            'sanitize_callback' => 'royal_jewellery_sanitize_select',
        ));
        $wp_customize->add_control('royal_jewellery_home_product',array(
            'type'    => 'select',
            'choices' => $cats,
            'label' => __('Select Product Category','royal-jewellery'),
            'section' => 'royal_jewellery_product_section',
        ));
    }

    // Pro Version
    $wp_customize->add_setting( 'pro_version_product', array(
        'sanitize_callback' => 'Royal_Jewellery_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Royal_Jewellery_Customize_Pro_Version ( $wp_customize,'pro_version_product', array(
        'section'     => 'royal_jewellery_product_section',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'royal-jewellery' ),
        'description' => esc_url( ROYAL_JEWELLERY_URL ),
        'priority'    => 100
    )));
    
    // Footer
    $wp_customize->add_section('royal_jewellery_site_footer_section', array(
        'title' => esc_html__('Footer', 'royal-jewellery'),
    ));

    $wp_customize->add_setting('royal_jewellery_show_hide_footer',array(
        'default' => true,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control('royal_jewellery_show_hide_footer',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Footer','royal-jewellery'),
        'section' => 'royal_jewellery_site_footer_section',
        'priority' => 1,
    ));

    $wp_customize->add_setting('royal_jewellery_footer_bg_image',array(
        'default'   => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'royal_jewellery_footer_bg_image',array(
        'label' => __('Footer Background Image','royal-jewellery'),
        'section' => 'royal_jewellery_site_footer_section',
        'priority' => 1,
    )));

    $wp_customize->add_setting('royal_jewellery_footer_bg_image_position',array(
        'default'=> 'scroll',
        'sanitize_callback' => 'royal_jewellery_sanitize_choices'
    ));
    $wp_customize->add_control('royal_jewellery_footer_bg_image_position',array(
        'type' => 'select',
        'label' => __('Footer Background Image Position','royal-jewellery'),
        'choices' => array(
            'fixed' => __('fixed','royal-jewellery'),
            'scroll' => __('scroll','royal-jewellery'),
        ),
        'section'=> 'royal_jewellery_site_footer_section',
    ));

    $wp_customize->add_setting('royal_jewellery_footer_widget_heading_alignment',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'royal_jewellery_sanitize_choices'
    ));
    $wp_customize->add_control('royal_jewellery_footer_widget_heading_alignment',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading Alignment','royal-jewellery'),
        'section' => 'royal_jewellery_site_footer_section',
        'choices' => array(
            'Left' => __('Left','royal-jewellery'),
            'Center' => __('Center','royal-jewellery'),
            'Right' => __('Right','royal-jewellery')
        ),
    ) );

    $wp_customize->add_setting('royal_jewellery_footer_widget_content_alignment',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'royal_jewellery_sanitize_choices'
    ));
    $wp_customize->add_control('royal_jewellery_footer_widget_content_alignment',array(
        'type' => 'select',
        'label' => __('Footer Widget Content Alignment','royal-jewellery'),
        'section' => 'royal_jewellery_site_footer_section',
        'choices' => array(
            'Left' => __('Left','royal-jewellery'),
            'Center' => __('Center','royal-jewellery'),
            'Right' => __('Right','royal-jewellery')
        ),
    ) );

    $wp_customize->add_setting('royal_jewellery_show_hide_copyright',array(
        'default' => true,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control('royal_jewellery_show_hide_copyright',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Copyright','royal-jewellery'),
        'section' => 'royal_jewellery_site_footer_section',
    ));

    $wp_customize->add_setting('royal_jewellery_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('royal_jewellery_footer_text_setting', array(
        'label' => __('Replace the footer text', 'royal-jewellery'),
        'section' => 'royal_jewellery_site_footer_section',
        'type' => 'text',
    ));

    $wp_customize->add_setting('royal_jewellery_copyright_content_alignment',array(
        'default' => 'Right',
        'transport' => 'refresh',
        'sanitize_callback' => 'royal_jewellery_sanitize_choices'
    ));
    $wp_customize->add_control('royal_jewellery_copyright_content_alignment',array(
        'type' => 'select',
        'label' => __('Copyright Content Alignment','royal-jewellery'),
        'section' => 'royal_jewellery_site_footer_section',
        'choices' => array(
            'Left' => __('Left','royal-jewellery'),
            'Center' => __('Center','royal-jewellery'),
            'Right' => __('Right','royal-jewellery')
        ),
    ) );

    $wp_customize->add_setting('royal_jewellery_copyright_background_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'royal_jewellery_copyright_background_color', array(
        'label'    => __('Copyright Background Color', 'royal-jewellery'),
        'section'  => 'royal_jewellery_site_footer_section',
    )));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_footer', array(
        'sanitize_callback' => 'Royal_Jewellery_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Royal_Jewellery_Customize_Pro_Version ( $wp_customize,'pro_version_footer', array(
        'section'     => 'royal_jewellery_site_footer_section',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'royal-jewellery' ),
        'description' => esc_url( ROYAL_JEWELLERY_URL ),
        'priority'    => 100
    )));

    // Post Settings
     $wp_customize->add_section('royal_jewellery_post_settings',array(
        'title' => esc_html__('Post Settings','royal-jewellery'),
        'priority'   =>40,
    ));

    $wp_customize->add_setting('royal_jewellery_post_page_title',array(
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('royal_jewellery_post_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Title', 'royal-jewellery'),
        'section'     => 'royal_jewellery_post_settings',
        'description' => esc_html__('Check this box to enable title on post page.', 'royal-jewellery'),
    ));

    $wp_customize->add_setting('royal_jewellery_post_page_meta',array(
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('royal_jewellery_post_page_meta',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Meta', 'royal-jewellery'),
        'section'     => 'royal_jewellery_post_settings',
        'description' => esc_html__('Check this box to enable meta on post page.', 'royal-jewellery'),
    ));

    $wp_customize->add_setting('royal_jewellery_post_page_thumb',array(
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('royal_jewellery_post_page_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Thumbnail', 'royal-jewellery'),
        'section'     => 'royal_jewellery_post_settings',
        'description' => esc_html__('Check this box to enable thumbnail on post page.', 'royal-jewellery'),
    ));

    $wp_customize->add_setting('royal_jewellery_post_page_content',array(
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('royal_jewellery_post_page_content',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Content', 'royal-jewellery'),
        'section'     => 'royal_jewellery_post_settings',
        'description' => esc_html__('Check this box to enable content on post page.', 'royal-jewellery'),
    ));

    $wp_customize->add_setting('royal_jewellery_post_page_btn',array(
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('royal_jewellery_post_page_btn',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Button', 'royal-jewellery'),
        'section'     => 'royal_jewellery_post_settings',
        'description' => esc_html__('Check this box to enable button on post page.', 'royal-jewellery'),
    ));

    $wp_customize->add_setting('royal_jewellery_single_post_thumb',array(
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('royal_jewellery_single_post_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Thumbnail', 'royal-jewellery'),
        'section'     => 'royal_jewellery_post_settings',
        'description' => esc_html__('Check this box to enable post thumbnail on single post.', 'royal-jewellery'),
    ));

    $wp_customize->add_setting( 'royal_jewellery_single_post_page_image_border_radius', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'royal_jewellery_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'royal_jewellery_single_post_page_image_border_radius', array(
        'label'       => esc_html__( 'Single Post Page Image Border Radius','royal-jewellery' ),
        'section'     => 'royal_jewellery_post_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    $wp_customize->add_setting( 'royal_jewellery_single_post_page_image_box_shadow', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'royal_jewellery_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'royal_jewellery_single_post_page_image_box_shadow', array(
        'label'       => esc_html__( 'Single Post Page Image Box Shadow','royal-jewellery' ),
        'section'     => 'royal_jewellery_post_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    $wp_customize->add_setting('royal_jewellery_single_post_page_content',array(
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('royal_jewellery_single_post_page_content',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Page Content', 'royal-jewellery'),
        'section'     => 'royal_jewellery_post_settings',
        'description' => esc_html__('Check this box to enable content on single post page.', 'royal-jewellery'),
    ));

    $wp_customize->add_setting('royal_jewellery_single_post_tags',array(
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('royal_jewellery_single_post_tags',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Tags', 'royal-jewellery'),
        'section'     => 'royal_jewellery_post_settings',
        'description' => esc_html__('Check this box to enable tags on single post.', 'royal-jewellery'),
    ));

    $wp_customize->add_setting('royal_jewellery_single_post_navigation_show_hide',array(
        'default' => true,
        'sanitize_callback' => 'royal_jewellery_sanitize_checkbox'
    ));
    $wp_customize->add_control('royal_jewellery_single_post_navigation_show_hide',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Post Navigation','royal-jewellery'),
        'section' => 'royal_jewellery_post_settings',
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_post_setting', array(
        'sanitize_callback' => 'Royal_Jewellery_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Royal_Jewellery_Customize_Pro_Version ( $wp_customize,'pro_version_post_setting', array(
        'section'     => 'royal_jewellery_post_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'royal-jewellery' ),
        'description' => esc_url( ROYAL_JEWELLERY_URL ),
        'priority'    => 100
    )));
}
add_action('customize_register', 'royal_jewellery_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function royal_jewellery_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function royal_jewellery_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function royal_jewellery_customize_preview_js(){
    wp_enqueue_script('royal-jewellery-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'royal_jewellery_customize_preview_js');

/*
** Load dynamic logic for the customizer controls area.
*/
function royal_jewellery_panels_js() {
    wp_enqueue_style( 'royal-jewellery-customizer-layout-css', get_theme_file_uri( '/assets/css/customizer-layout.css' ) );
    wp_enqueue_script( 'royal-jewellery-customize-layout', get_theme_file_uri( '/assets/js/customize-layout.js' ), array(), '1.2', true );
}
add_action( 'customize_controls_enqueue_scripts', 'royal_jewellery_panels_js' );